pub struct CanTx<'d> { /* private fields */ }Expand description
FDCAN Tx only Instance
Implementations
Sourceimpl<'c, 'd> CanTx<'d>
impl<'c, 'd> CanTx<'d>
Sourcepub async fn write(&mut self, frame: &Frame) -> Option<Frame>
pub async fn write(&mut self, frame: &Frame) -> Option<Frame>
Queues the message to be sent but exerts backpressure. If a lower-priority frame is dropped from the mailbox, it is returned. If no lower-priority frames can be replaced, this call asynchronously waits for a frame to be successfully transmitted, then tries again.
Sourcepub fn blocking_write(&mut self, frame: &Frame) -> Option<Frame>
pub fn blocking_write(&mut self, frame: &Frame) -> Option<Frame>
Blocking write frame.
If the TX queue is full, this will wait until there is space.
Sourcepub async fn write_fd(&mut self, frame: &FdFrame) -> Option<FdFrame>
pub async fn write_fd(&mut self, frame: &FdFrame) -> Option<FdFrame>
Queues the message to be sent but exerts backpressure. If a lower-priority frame is dropped from the mailbox, it is returned. If no lower-priority frames can be replaced, this call asynchronously waits for a frame to be successfully transmitted, then tries again.
Sourcepub fn blocking_write_fd(&mut self, frame: &FdFrame) -> Option<FdFrame>
pub fn blocking_write_fd(&mut self, frame: &FdFrame) -> Option<FdFrame>
Blocking write FD frame.
If the TX queue is full, this will wait until there is space.
Sourcepub async fn write_marked(&mut self, frame: &Frame, marker: u8) -> Option<Frame>
pub async fn write_marked(&mut self, frame: &Frame, marker: u8) -> Option<Frame>
Like Self::write, but stores a TX event carrying marker once the frame
has been sent. Read it back with Self::dequeue_tx_event.
Sourcepub async fn write_fd_marked(
&mut self,
frame: &FdFrame,
marker: u8,
) -> Option<FdFrame>
pub async fn write_fd_marked( &mut self, frame: &FdFrame, marker: u8, ) -> Option<FdFrame>
Like Self::write_fd, but stores a TX event carrying marker once the
frame has been sent. Read it back with Self::dequeue_tx_event.